"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.APIGatewayHelper = void 0;
const AWS = require("aws-sdk");
const typescript_helper_functions_1 = require("typescript-helper-functions");
/**
 * APIGateway Helper
 */
class APIGatewayHelper extends typescript_helper_functions_1.BaseClass {
    /**
     * Initializes new instance of APIGatewayHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.APIGateway} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.APIGateway.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger, repository, options) {
        super(logger);
        this.Repository = repository || new AWS.APIGateway(options);
    }
    /**
     * Create an API key
     * @param name {string} Name of new API key
     * @param description {string} Description of new API key
     * @param value {string} Value to give new API key. If not provided, will be auto generated
     */
    CreateApiKeyAsync(name, description, value) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${APIGatewayHelper.name}.${this.CreateApiKeyAsync.name}`;
            this.LogHelper.LogInputs(action, { name, description, value });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(name)) {
                throw new Error(`[${action}]-Must supply name`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(description)) {
                throw new Error(`[${action}]-Must supply description`);
            }
            // create params object
            const params = {
                description,
                name,
            };
            if (this.ObjectOperations.IsNullOrWhitespace(value)) {
                params.generateDistinctId = true;
            }
            else {
                params.value = value;
            }
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.createApiKey(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    /**
     * Create an usage plan
     * @param name {string} Usage plan name
     * @param description {string} Usage plan description
     * @param apiStages {AWS.APIGateway.ApiStage[]} API stages to attach this usage plan to
     * @param quota {AWS.APIGateway.QuotaSettings} Quota settings
     * @param throttle {AWS.APIGateway.ThrottleSettings} Throttle settings
     */
    CreateUsagePlanAsync(name, description, apiStages, quota, throttle) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${APIGatewayHelper.name}.${this.CreateUsagePlanAsync.name}`;
            this.LogHelper.LogInputs(action, { name, description, apiStages, quota, throttle });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(name)) {
                throw new Error(`[${action}]-Must supply name`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(description)) {
                throw new Error(`[${action}]-Must supply description`);
            }
            if (!apiStages || apiStages.length === 0) {
                throw new Error(`[${action}]-Must supply at least one apiStage`);
            }
            // create params object
            const params = {
                apiStages,
                description,
                name,
                quota,
                throttle,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.createUsagePlan(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    /**
     * Create an usage plan key
     * @param keyId {string} ID of usage plan key
     * @param keyType {string} Type of key to create
     * @param usagePlanId {string} Usage plan id to associate with
     */
    CreateUsagePlanKeyAsync(keyId, keyType, usagePlanId) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${APIGatewayHelper.name}.${this.CreateUsagePlanKeyAsync.name}`;
            this.LogHelper.LogInputs(action, { keyId, keyType, usagePlanId });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(keyId)) {
                throw new Error(`[${action}]-Must supply keyId`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(keyType)) {
                throw new Error(`[${action}]-Must supply keyType`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(usagePlanId)) {
                throw new Error(`[${action}]-Must supply usagePlanId`);
            }
            // create params object
            const params = {
                keyId,
                keyType,
                usagePlanId,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.createUsagePlanKey(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    /**
     * Delete an API key
     * @param apiKey {string} API key to delete
     */
    DeleteApiKeyAsync(apiKey) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${APIGatewayHelper.name}.${this.DeleteApiKeyAsync.name}`;
            this.LogHelper.LogInputs(action, { apiKey });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(apiKey)) {
                throw new Error(`[${action}]-Must supply apiKey`);
            }
            // create params object
            const params = {
                apiKey,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.deleteApiKey(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    /**
     * Delete an usage plan
     * @param usagePlanId {string} Usage plan to delete
     */
    DeleteUsagePlanAsync(usagePlanId) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${APIGatewayHelper.name}.${this.DeleteUsagePlanAsync.name}`;
            this.LogHelper.LogInputs(action, { usagePlanId });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(usagePlanId)) {
                throw new Error(`[${action}]-Must supply usagePlanId`);
            }
            // create params object
            const params = {
                usagePlanId,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.deleteUsagePlan(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    /**
     * Delete an usage plan key
     * @param keyId {string} Key to delete
     * @param usagePlanId {string} Usage plan that is associated with this key
     */
    DeleteUsagePlanKeyAsync(keyId, usagePlanId) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${APIGatewayHelper.name}.${this.DeleteUsagePlanKeyAsync.name}`;
            this.LogHelper.LogInputs(action, { keyId, usagePlanId });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(keyId)) {
                throw new Error(`[${action}]-Must supply keyId`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(usagePlanId)) {
                throw new Error(`[${action}]-Must supply usagePlanId`);
            }
            // create params object
            const params = {
                keyId,
                usagePlanId,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.deleteUsagePlanKey(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    /**
     * Get an API key
     * @param apiKey {string} API Key
     */
    GetApiKeyAsync(apiKey) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${APIGatewayHelper.name}.${this.GetApiKeyAsync.name}`;
            this.LogHelper.LogInputs(action, { apiKey });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(apiKey)) {
                throw new Error(`[${action}]-Must supply apiKey`);
            }
            // create params object
            const params = {
                apiKey,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.getApiKey(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
}
exports.APIGatewayHelper = APIGatewayHelper;
//# sourceMappingURL=helper.js.map